Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(297)

Unified Diff: mandoline/services/core_services/core_services_application_delegate.h

Issue 1679573002: Move shell interfaces into the shell.mojom namespace. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@delegate
Patch Set: . Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: mandoline/services/core_services/core_services_application_delegate.h
diff --git a/mandoline/services/core_services/core_services_application_delegate.h b/mandoline/services/core_services/core_services_application_delegate.h
index 4398aec5c67f62e113fe36f7eac8a69b7414e4de..1c43659ddaa372c27111c479174c9a1ecb0b2485 100644
--- a/mandoline/services/core_services/core_services_application_delegate.h
+++ b/mandoline/services/core_services/core_services_application_delegate.h
@@ -23,8 +23,8 @@ class ApplicationThread;
// instance of the CoreServices ServiceProvider.
class CoreServicesApplicationDelegate
: public mojo::ApplicationDelegate,
- public mojo::InterfaceFactory<mojo::ContentHandler>,
- public mojo::ContentHandler {
+ public mojo::InterfaceFactory<mojo::shell::mojom::ContentHandler>,
+ public mojo::shell::mojom::ContentHandler {
public:
CoreServicesApplicationDelegate();
~CoreServicesApplicationDelegate() override;
@@ -38,18 +38,20 @@ class CoreServicesApplicationDelegate
mojo::ApplicationConnection* connection) override;
void Quit() override;
- // Overridden from mojo::InterfaceFactory<mojo::ContentHandler>:
- void Create(mojo::ApplicationConnection* connection,
- mojo::InterfaceRequest<mojo::ContentHandler> request) override;
+ // Overridden from mojo::InterfaceFactory<mojo::shell::mojom::ContentHandler>:
+ void Create(
+ mojo::ApplicationConnection* connection,
+ mojo::InterfaceRequest<mojo::shell::mojom::ContentHandler>
+ request) override;
- // Overridden from mojo::ContentHandler:
+ // Overridden from mojo::shell::mojom::ContentHandler:
void StartApplication(
- mojo::InterfaceRequest<mojo::Application> request,
+ mojo::InterfaceRequest<mojo::shell::mojom::Application> request,
mojo::URLResponsePtr response,
const mojo::Callback<void()>& destruct_callback) override;
// Bindings for all of our connections.
- mojo::WeakBindingSet<ContentHandler> handler_bindings_;
+ mojo::WeakBindingSet<mojo::shell::mojom::ContentHandler> handler_bindings_;
ScopedVector<ApplicationThread> application_threads_;
mojo::TracingImpl tracing_;
« no previous file with comments | « content/renderer/render_frame_impl.cc ('k') | mandoline/services/core_services/core_services_application_delegate.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698